@@ -144,12 +144,15 @@ class EQU:
         self.rho_tor = np.sqrt(np.abs(self.tfl/(np.pi*self.B0[..., None])))
         ## Normalised rho toroidal
         self.rho_tor_n = np.zeros_like(self.tfl)
+        self.rhotor_trapz = np.zeros_like(self.tfl) # for RABBIT
         ## Normalised toroidal flux [Vs]
         self.tfln = np.zeros_like(self.tfl)
         for jt in range(nt):
             tf = self.tfl[jt]
+            torflux_trapz = cumtrapz(-self.q[jt], x=self.pfl[jt], initial=0.)
             self.tfln[jt, :] = tf/tf[-1]
             self.rho_tor_n[jt, 1:] = np.sqrt((tf[1:] - tf[0])/(tf[-1] - tf[0]))
+            self.rhotor_trapz[jt, 1:] = np.sqrt( torflux_trapz[1:] / (torflux_trapz[-1] - torflux_trapz[0]) )
 
         self.pfm = self.pfm[:, :, indt]
 
